# -*- coding: utf-8 -*-

"""
This module allows to consult execution output clusters, in parallel case
only output of processor 0 is shown.
A regular expression could be used to search only matching lines of output.

These asrun customizations are called through (in asrun configuration file) :

    schema_tail :  plugins.tail_slurm.tail

"""

from asrun.core import magic
from asrun.common_func import flash_filename
from asrun.job import Func_actu


def tail(prof, args, print_output=True, **kwargs):
    """Custom tail reading the output in flash directory"""

    jobid = prof['jobid'][0]
    jobname = prof['nomjob'][0]
    mode = prof['mode'][0]
    nbline = prof['tail_nbline'][0]
    regexp = prof['tail_regexp'][0]
    run=magic.run

    regexpPar = '^\[[1-9]+\]'
    cmdPar = 'egrep -v -- \'%s\' ' % regexpPar

    if regexp is None or regexp.strip() == "":
        cmd = ' | tail -%s ' % nbline
    else:
        cmd = ' | egrep -- \'%s\' ' % regexp

    etat, diag, node, tcpu, wrk, queue = Func_actu(run, jobid, jobname, mode)

    jret = 0
    s_out = ''

    if etat == 'RUN':
        fich = flash_filename("flasheur", jobname, jobid, "output")
        if run.Exists(fich):
            cmde = cmdPar + fich + cmd
            jret, s_out = run.Shell(cmde, mach='')
    magic.run.PrintExitCode = False
    magic.run.Mess(s_out)
    return jret
